use strict;
use warnings FATAL => 'all';
use Test::More;
use DBIx::Data::Collection::Set::IndexableBy;

BEGIN {
  package BasicCollection;
  require 't/01basic_collection.t'
}

sub setup_db { BasicCollection::setup_db @_ }

sub make_store { BasicCollection::make_store @_ }

sub make_set {
  BasicCollection::make_set({
      indexable_by => {
        name => {
          set_over => [ 'name' ],
          store => make_store({
            select_single_sql => q{SELECT id, name FROM person WHERE name = ?},
            select_single_argument_order => [ qw(name) ],
          }),
        },
      },
    },
    {
      select_single_sql => q{SELECT id, name FROM person WHERE id = ?},
      select_single_argument_order => [ qw(id) ],
    },
    'DBIx::Data::Collection::Set::IndexableBy'
  )
}


sub run_tests {
  my @expect = setup_db;
  my $set = make_set;
  use Devel::Dwarn;
  Dwarn $set->get({ id => 1 });
  my $by_name = $set->indexed_by('name');
  Dwarn $by_name->get({ name => 'Pterry' });
  done_testing;
}

run_tests unless caller;
